local mod = RW:Boss("Deathbringer Saurfang", "Icecrown Citadel", "The Lower Spire")
local L

mod.BossIcon = [[Interface\Icons\achievement_boss_saurfang]]

---------------------------
-- Variables
local tActive
local tAddsCD, wAdds
local mMark, wMarkSoon, wMark
local wFrenzy
local mRune, tRuneDur, tRuneCD
--local tBoil, mBoil
local tBerserk

---------------------------
-- Init

function mod:OnRegister()
	L = mod:RegisterLocale("enUS")
	if L then
		L.YellPullHorde = "Kor'kron, move out! Champions, watch your backs. The Scourge have been..."
		L.YellPullAlliance = " For every Horde soldier that you killed, for every Alliance dog that fell, the Lich King's armies grew. Even now the Val'kyr work to raise your fallen... As Scourge."
		L.YellWin = "I... Am... Released..."
		
		L.active = " active"
		L.active_opt = "Timer for when the fight starts"
		L.active_grup = "Fight start"
		
		L.blood_opt = "Blood Power \"health\" frame"
		L.blood = "Blood Power"
		
		L.mark_soon = "Mark of the Fallen Champion soon"
		L.mark_soon_opt = "Warning at 90 stacks"
	end
	L = mod:GetLocale()
	self.L = L
	
	self:SetTrigger(L.YellPullHorde, L.YellPullAlliance, 37813)
	self:SetWin()
	self:SetDelay(120)
	
	self:AddBoolOption("BloodPFrame", L.blood_opt, nil, nil, select(3, GetSpellInfo(72370)))
	
	tBerserk	= self:BerserkTimer(480)
	
	tActive		= self:CustomTimer(98, (RW.LBB[self:GetName()] or self:GetName())..L.active, L.active_opt, select(3, GetSpellInfo(72370)),  L.active_grup)
	tAddsCD		= self:CDTimer(39, 72173)
	tRuneDur	= self:DurTargetTimer(20 ,72410)
	tRuneCD		= self:CDTimer(30, 72410)
	
	wAdds		= self:Warning(72173)
	wMarkSoon	= self:CustomWarning(L.mark_soon, L.mark_soon_opt, 72293)
	wFrenzy		= self:Warning(72737)
	wMark		= self:Warning(72293)
	
	mMark		= self:TargetMessage(72293)
	mRune		= self:TargetMessage(72410)
end

---------------------------
-- Locals
local bloodStacks
local markSpamm
local markCount
local summonSpamm

local function updateBlood()	
	local uID = mod:UIDFromCID(37813)
	if uID then
		bloodStacks = UnitPower(uID) / UnitPowerMax(uID)
	end
	if bloodStacks > 0.85 then
		if not markSpamm then
			wMarkSoon:Show()
			markSpamm = true
		end
	end
	return bloodStacks
end

---------------------------
-- Start

function mod:OnEngage(trigger)
	self:Track("Adds", 72173, 72357, 72356, 72358, 72172)
	self:Track("Mark", 72254, 72280, 72293, 72444, 72445, 72279, 72260, 72278, 72255, 72256, 72446) -- 72293 is the one cast and applied, remove the rest after comfirm
	self:Track("Frenzy", 72737)
	self:Track("Rune", 72410, 72408, 72409, 72447, 72448, 72449)
	
	markSpamm = false
	summonSpamm = 0
	markCount = 0
	bloodStacks = 0
	
	if self.db.profile.BloodPFrame then
		self:SendMessage("RW_AddHealthFrame", updateBlood, L.blood, select(3, GetSpellInfo(72370)))
	end
	
	if UnitFactionGroup("player") == "Horde" then
		tActive:Start()
		tAddsCD:Schedule(98)
		tBerserk:Schedule(100)
	else
		tActive:Start(48)
		tAddsCD:Schedule(48)
		tBerserk:Schedule(48)
	end
	
	self:SendMessage("RW_ShowRangeCheck", true, 12)
end

function mod:Adds(event, args)
	if event == "SPELL_CAST_SUCCESS" then
		if (GetTime() - summonSpamm) > 2 then			
			wAdds:Show()
			summonSpamm = GetTime()
		end
		tAddsCD:Start()
	end
end

function mod:Mark(event, args)
	if event == "SPELL_AURA_APPLIED" then
		if args:IsPlayer() then
			wMark:Show()
		end
		mMark:Show(args.dName)
		markCount = markCount + 1
		markSpamm = false
	end
end

function mod:Frenzy(event, args)
	if event == "SPELL_AURA_APPLIED" then
		wFrenzy:Show()
	end
end

function mod:Rune(event, args)
	if event == "SPELL_AURA_APPLIED" then
		tRuneDur:Start(args.dName)
		mRune:Show(args.dName)
		tRuneCD:Start()
	end
end
